import { Module, Post } from '@nestjs/common';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { GraphQLModule } from '@nestjs/graphql';
import { ApolloDriver, ApolloDriverConfig } from '@nestjs/apollo';
import { join } from 'path';
import { MemberResolver } from './services/reputation/components/member/member.resolver';
import { PostResolver } from './services/reputation/components/post/post.resolver';
import { CitationsResolver } from './services/reputation/components/citation/citation.resolver';

@Module({
  imports: [
    GraphQLModule.forRoot<ApolloDriverConfig>({
      driver: ApolloDriver,
      typePaths: ['./**/*.graphql'],
      definitions: {
        path: join(process.cwd(), 'src/graphql.ts')
      },
    }),
  ],
  controllers: [AppController],
  providers: [AppService, MemberResolver, PostResolver, CitationsResolver],
})
export class AppModule {}
